IntelMQ — intelmq 3.1.0.alpha1 documentation

# IntelMQ

IntelMQ is a solution for IT security teams (CERTs & CSIRTs, SOCs abuse departments, etc.) for collecting and processing security feeds (such as log files) using a message queuing protocol. It’s a community driven initiative called IHAP (Incident Handling Automation Project) which was conceptually designed by European CERTs/CSIRTs during several InfoSec events. Its main goal is to give to incident responders an easy way to collect & process threat intelligence thus improving the incident handling processes of CERTs.

## User guide

- Introduction
- Hardware Requirements
- Installation
- Upgrade instructions
- Configuration and Management
- Bots
- intelmqctl documentation
- Feeds
- Frequently asked questions
- IntelMQ API
- IntelMQ Manager

## Connecting with other systems

- IntelMQ Ecosystem
- ELK Stack
- MISP integrations in IntelMQ
- IntelMQ - n6 Integration
- EventDB
- Abuse-contact look-ups

## Getting involved

- Developers Guide
- Data Format
- Harmonization field names
- Release procedure
- Feeds wishlist

## Licence

This software is licensed under GNU Affero General Public License version 3

## Funded by

This project was partially funded by the CEF framework

## Indices and tables

- Index

- Module Index

- Search Page